summaryrefslogtreecommitdiffhomepage
path: root/digital/beacon/src/laser.c
diff options
context:
space:
mode:
Diffstat (limited to 'digital/beacon/src/laser.c')
-rw-r--r--digital/beacon/src/laser.c13
1 files changed, 10 insertions, 3 deletions
diff --git a/digital/beacon/src/laser.c b/digital/beacon/src/laser.c
index 232ff229..4bd78c5c 100644
--- a/digital/beacon/src/laser.c
+++ b/digital/beacon/src/laser.c
@@ -91,14 +91,21 @@ void laser_engage_angle_confirmation(uint16_t value)
}
-/* This function returns the angle value */
-uint16_t laser_get_angle(void)
+/* This function returns the angle value in raw format */
+uint16_t laser_get_angle_raw(void)
{
+ uprintf("valeur de laser_get_angle_raw() = %d\r\n",laser.angle);
return laser.angle;
}
+/* This function returns the angle value in degree */
+float laser_get_angle_degree(void)
+{
+ return codewheel_convert_angle_raw2degrees(laser.angle);
+}
+
-/* This function sets the angle value */
+/* This function sets the angle value in raw format */
void laser_set_angle(uint16_t angle)
{
laser.angle = angle;